@@ -45,7 +45,6 @@
 #include "rom89.h"
 #include "romdump.h"
 #include "keys89.h"
-#include "keys92p.h"
 
 // Screen coordinates of the TI89
 #define TI89_ROWS          128
@@ -67,54 +66,6 @@ static int		send_key	(CalcHandle* handle, uint16_t key)
 {
 	TRYF(ti89_send_KEY(key));
 	TRYF(ti89_recv_ACK(&key));
-	PAUSE(50);
-
-	return 0;
-}
-
-static int		execute		(CalcHandle* handle, VarEntry *ve, const char* args)
-{
-	unsigned int i;
-
-	if(ve->type == TI89_APPL)
-		return ERR_VOID_FUNCTION;
-
-	// Go back to homescreen
-	PAUSE(200);
-	if(handle->model == CALC_TI89 || handle->model == CALC_TI89T)
-	  {
-	    TRYF(send_key(handle, KEY89_HOME));
-	    TRYF(send_key(handle, KEY89_CLEAR));
-	    TRYF(send_key(handle, KEY89_CLEAR));
-	  }
-	else if(handle->model == CALC_TI92P || handle->model == CALC_V200)
-	  {
-	    // TI92+ or V200
-	    TRYF(send_key(handle, KEY92P_CTRL + KEY92P_Q));
-	    TRYF(send_key(handle, KEY92P_CLEAR));
-	    TRYF(send_key(handle, KEY92P_CLEAR));
-	  }
-
-	// Launch program by remote control
-	for(i = 0; i < strlen(ve->folder); i++)
-		TRYF(send_key(handle, (ve->folder)[i]));
-
-    if(strcmp(ve->folder, ""))
-		TRYF(send_key(handle, '\\'));
-
-	for(i = 0; i < strlen(ve->name); i++)
-		TRYF(send_key(handle, (ve->name)[i]));
-
-	TRYF(send_key(handle, KEY89_LP));
-	if(args)
-	{
-		for(i = 0; i < strlen(args); i++)
-			TRYF(send_key(handle, args[i]));
-	}
-    TRYF(send_key(handle, KEY89_RP));
-
-    TRYF(send_key(handle, KEY89_ENTER));
-	PAUSE(200);
 
 	return 0;
 }
@@ -152,7 +103,7 @@ static int		recv_screen	(CalcHandle* handle, CalcScreenCoord* sc, uint8_t** bitm
 	if(err != ERR_CHECKSUM) { TRYF(err) };
 	TRYF(ti89_send_ACK());
 
-	*bitmap = (uint8_t *)g_malloc(TI89_COLS * TI89_ROWS / 8);
+	*bitmap = (uint8_t *) malloc(TI89_COLS * TI89_ROWS / 8);
 	if(*bitmap == NULL) 
 		return ERR_MALLOC;
 	memcpy(*bitmap, buf, TI89_COLS * TI89_ROWS / 8);
@@ -171,7 +122,7 @@ static int		recv_screen	(CalcHandle* handle, CalcScreenCoord* sc, uint8_t** bitm
 	return 0;
 }
 
-static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
+static int		get_dirlist	(CalcHandle* handle, TNode** vars, TNode** apps)
 {
 	TreeInfo *ti;
 	VarEntry info;
@@ -179,22 +130,22 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 	uint8_t buffer[65536];
     int i, j;
     uint8_t extra = (handle->model == CALC_V200) ? 8 : 0;
-	GNode *root;
+	TNode *root;
 
-	(*apps) = g_node_new(NULL);
-	ti = (TreeInfo *)g_malloc(sizeof(TreeInfo));
+	(*apps) = t_node_new(NULL);
+	ti = (TreeInfo *)malloc(sizeof(TreeInfo));
 	ti->model = handle->model;
 	ti->type = APP_NODE_NAME;
 	(*apps)->data = ti;
 
-    (*vars) = g_node_new(NULL);
-	ti = (TreeInfo *)g_malloc(sizeof(TreeInfo));
+    (*vars) = t_node_new(NULL);
+	ti = (TreeInfo *)malloc(sizeof(TreeInfo));
 	ti->model = handle->model;
 	ti->type = VAR_NODE_NAME;
 	(*vars)->data = ti;
 
-	root = g_node_new(NULL);
-	g_node_append(*apps, root);
+	root = t_node_new(NULL);
+	t_node_append(*apps, root);
 
     TRYF(ti89_send_REQ(TI89_FDIR << 24, TI89_RDIR, ""));
     TRYF(ti89_recv_ACK(NULL));
@@ -214,7 +165,7 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 	for(j = 4; j < (int)block_size;) 
 	{
 		VarEntry *fe = tifiles_ve_create();
-        GNode *node;
+        TNode *node;
 
         memcpy(fe->name, buffer + j, 8);
         fe->name[8] = '\0';
@@ -232,8 +183,8 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 
         if(fe->type == TI89_DIR)
 		{
-			node = g_node_new(fe);
-			g_node_append(*vars, node);
+			node = t_node_new(fe);
+			t_node_append(*vars, node);
 		}
         else if(fe->type == TI89_APPL)
 		{
@@ -243,9 +194,9 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 	}
 
 	// get list of variables into each folder
-	for(i = 0; i < (int)g_node_n_children(*vars); i++) 
+	for(i = 0; i < (int)t_node_n_children(*vars); i++) 
 	{
-		GNode *folder = g_node_nth_child(*vars, i);
+		TNode *folder = t_node_nth_child(*vars, i);
 		char *folder_name = ((VarEntry *) (folder->data))->name;
 		char *u1, *u2;
 
@@ -269,7 +220,7 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 		for(j = 4 + 14 + extra; j < (int)block_size;) 
 		{
 			VarEntry *ve = tifiles_ve_create();
-			GNode *node;
+			TNode *node;
 
 			memcpy(ve->name, buffer + j, 8);
 			ve->name[8] = '\0';
@@ -285,23 +236,19 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 			ve->attr,
 			ve->size);
 
-			u1 = ticonv_varname_to_utf8(handle->model, ((VarEntry *) (folder->data))->name, -1);
-			u2 = ticonv_varname_to_utf8(handle->model, ve->name, ve->type);
+			u1 = ticonv_varname_to_utf8(handle->model, ((VarEntry *) (folder->data))->name);
+			u2 = ticonv_varname_to_utf8(handle->model, ve->name);
 			g_snprintf(update_->text, sizeof(update_->text), _("Parsing %s/%s"), u1, u2);
 			g_free(u1); g_free(u2);
 			update_label();
 
 			if(ve->type == TI89_APPL) 
 			{
-				VarEntry arg;
-
-				memset(&arg, 0, sizeof(arg));
-				strcpy(arg.name, ve->name);
-				if(!ticalcs_dirlist_ve_exist(*apps, &arg))
+				if(!ticalcs_dirlist_ve_exist(*apps, ve->name))
 				{
 					strcpy(ve->folder, "");
-					node = g_node_new(ve);
-					g_node_append(root, node);
+					node = t_node_new(ve);
+					t_node_append(root, node);
 				}
 			} 
 			else
@@ -313,8 +260,8 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 				}
 				else
 				{
-					node = g_node_new(ve);
-					g_node_append(folder, node);
+					node = t_node_new(ve);
+					t_node_append(folder, node);
 				}
 			}
 		}
@@ -361,7 +308,7 @@ static int		send_var	(CalcHandle* handle, CalcMode mode, FileContent* content)
 			tifiles_build_fullname(handle->model, varname, entry->folder, entry->name);
 		}
 
-		utf8 = ticonv_varname_to_utf8(handle->model, varname, vartype);
+		utf8 = ticonv_varname_to_utf8(handle->model, varname);
 		g_snprintf(update_->text, sizeof(update_->text), "%s", utf8);
 		g_free(utf8);
 		update_label();
@@ -407,7 +354,7 @@ static int		recv_var	(CalcHandle* handle, CalcMode mode, FileContent* content, V
 	memcpy(ve, vr, sizeof(VarEntry));
 
 	tifiles_build_fullname(handle->model, varname, vr->folder, vr->name);
-	utf8 = ticonv_varname_to_utf8(handle->model, varname, vr->type);
+	utf8 = ticonv_varname_to_utf8(handle->model, varname);
 	g_snprintf(update_->text, sizeof(update_->text), "%s", utf8);
 	g_free(utf8);
 	update_label();
@@ -486,7 +433,7 @@ static int		send_var_ns	(CalcHandle* handle, CalcMode mode, FileContent* content
 			tifiles_build_fullname(handle->model, varname, entry->folder, entry->name);
 		}
 
-		utf8 = ticonv_varname_to_utf8(handle->model, varname, vartype);
+		utf8 = ticonv_varname_to_utf8(handle->model, varname);
 		g_snprintf(update_->text, sizeof(update_->text), "%s", utf8);
 		g_free(utf8);
 		update_label();
@@ -555,7 +502,7 @@ static int		recv_var_ns	(CalcHandle* handle, CalcMode mode, FileContent* content
             strcpy(ve->name, tipath);
         }
 
-		utf8 = ticonv_varname_to_utf8(handle->model, ve->name, ve->type);
+		utf8 = ticonv_varname_to_utf8(handle->model, ve->name);
 		g_snprintf(update_->text, sizeof(update_->text), "%s", utf8);
 		g_free(utf8);
 		update_label();
@@ -594,7 +541,7 @@ static int		send_flash	(CalcHandle* handle, FlashContent* content)
 		ticalcs_info(_("FLASH name: \"%s\""), ptr->name);
 		ticalcs_info(_("FLASH size: %i bytes."), ptr->data_length);
 
-		utf8 = ticonv_varname_to_utf8(handle->model, ptr->name, ptr->data_type);
+		utf8 = ticonv_varname_to_utf8(handle->model, ptr->name);
 		g_snprintf(update_->text, sizeof(update_->text), "%s", utf8);
 		g_free(utf8);
 		update_label();
@@ -616,7 +563,7 @@ static int		send_flash	(CalcHandle* handle, FlashContent* content)
 		}
 
 		nblocks = ptr->data_length / 65536;
-		update_->max2 = nblocks+1;
+		update_->max2 = nblocks;
 
 		for(i = 0; i <= nblocks; i++) 
 		{
@@ -655,7 +602,7 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 	int i;
 	char *utf8;
 
-	utf8 = ticonv_varname_to_utf8(handle->model, vr->name, vr->type);
+	utf8 = ticonv_varname_to_utf8(handle->model, vr->name);
 	g_snprintf(update_->text, sizeof(update_->text), "%s", utf8);
 	g_free(utf8);
 	update_label();
@@ -740,23 +687,6 @@ static int		recv_idlist	(CalcHandle* handle, uint8_t* idlist)
 
 static int		dump_rom_1	(CalcHandle* handle)
 {
-	// Go back to homescreen
-	PAUSE(200);
-	if(handle->model == CALC_TI89 || handle->model == CALC_TI89T)
-	  {
-	    TRYF(send_key(handle, KEY89_HOME));
-	    TRYF(send_key(handle, KEY89_CLEAR));
-	    TRYF(send_key(handle, KEY89_CLEAR));
-	  }
-	else if(handle->model == CALC_TI92P || handle->model == CALC_V200)
-	  {
-	    // TI92+ or V200
-	    TRYF(send_key(handle, KEY92P_CTRL + KEY92P_Q));
-	    TRYF(send_key(handle, KEY92P_CLEAR));
-	    TRYF(send_key(handle, KEY92P_CLEAR));
-	  }
-	PAUSE(200);
-
 	// Send dumping program
 	TRYF(rd_send(handle, "romdump.89z", romDumpSize89, romDump89));
 	PAUSE(1000);
@@ -768,6 +698,13 @@ static int		dump_rom_1	(CalcHandle* handle)
 static int		dump_rom_2	(CalcHandle* handle, CalcDumpSize size, const char *filename)
 {
 	// Launch program by remote control
+	PAUSE(200);
+	TRYF(send_key(handle, KEY89_HOME));
+	PAUSE(50);
+	TRYF(send_key(handle, KEY89_CLEAR));
+	PAUSE(50);
+	TRYF(send_key(handle, KEY89_CLEAR));
+	PAUSE(50);
     TRYF(send_key(handle, 'm'));
     TRYF(send_key(handle, 'a'));
     TRYF(send_key(handle, 'i'));
@@ -868,7 +805,7 @@ static int		del_var		(CalcHandle* handle, VarRequest* vr)
 	char *utf8;
 
 	tifiles_build_fullname(handle->model, varname, vr->folder, vr->name);
-	utf8 = ticonv_varname_to_utf8(handle->model, varname, vr->type);
+	utf8 = ticonv_varname_to_utf8(handle->model, varname);
 	g_snprintf(update_->text, sizeof(update_->text), _("Deleting %s..."), utf8);
 	g_free(utf8);
 	update_label();
@@ -887,7 +824,7 @@ static int		new_folder  (CalcHandle* handle, VarRequest* vr)
 	char *utf8;
 
 	tifiles_build_fullname(handle->model, varname, vr->folder, "a1234567");
-	utf8 = ticonv_varname_to_utf8(handle->model, vr->folder, -1);
+	utf8 = ticonv_varname_to_utf8(handle->model, vr->folder);
 	g_snprintf(update_->text, sizeof(update_->text), _("Creating %s..."), utf8);
 	g_free(utf8);
 	update_label();
@@ -996,8 +933,8 @@ const CalcFncts calc_89 =
 {
 	CALC_TI89,
 	"TI89",
-	"TI-89",
-	"TI-89",
+	N_("TI-89"),
+	N_("TI-89"),
 	OPS_ISREADY | OPS_KEYS | OPS_SCREEN | OPS_DIRLIST | OPS_BACKUP | OPS_VARS | 
 	OPS_FLASH | OPS_IDLIST | OPS_CLOCK | OPS_ROMDUMP |
 	OPS_DELVAR | OPS_NEWFLD | OPS_VERSION |
@@ -1006,7 +943,6 @@ const CalcFncts calc_89 =
 		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
-	&execute,
 	&recv_screen,
 	&get_dirlist,
 	&get_memfree,
@@ -1035,8 +971,8 @@ const CalcFncts calc_92p =
 {
 	CALC_TI92P,
 	"TI92+",
-	"TI-92 Plus",
-	"TI-92 Plus",
+	N_("TI-92 Plus"),
+	N_("TI-92 Plus"),
 	OPS_ISREADY | OPS_KEYS | OPS_SCREEN | OPS_DIRLIST | OPS_BACKUP | OPS_VARS | 
 	OPS_FLASH | OPS_IDLIST | OPS_CLOCK | OPS_ROMDUMP |
 	OPS_DELVAR | OPS_NEWFLD | OPS_VERSION | OPS_OS |
@@ -1045,7 +981,6 @@ const CalcFncts calc_92p =
 		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
-	&execute,
 	&recv_screen,
 	&get_dirlist,
 	&get_memfree,
@@ -1073,9 +1008,9 @@ const CalcFncts calc_92p =
 const CalcFncts calc_89t = 
 {
 	CALC_TI89T,
-	"Titanium",
-	"TI-89 Titanium",
-	"TI-89 Titanium",
+	"TI89t",
+	N_("TI-89 Titanium"),
+	N_("TI-89 Titanium"),
 	OPS_ISREADY | OPS_KEYS | OPS_SCREEN | OPS_DIRLIST | OPS_BACKUP | OPS_VARS | 
 	OPS_FLASH | OPS_IDLIST | OPS_CLOCK | OPS_ROMDUMP | 
 	OPS_DELVAR | OPS_NEWFLD | OPS_VERSION | OPS_OS |
@@ -1084,7 +1019,6 @@ const CalcFncts calc_89t =
 		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
-	&execute,
 	&recv_screen,
 	&get_dirlist,
 	&get_memfree,
@@ -1113,7 +1047,7 @@ const CalcFncts calc_v2 =
 {
 	CALC_V200,
 	"V200",
-	"V200PLT",
+	N_("V200PLT"),
 	N_("V200 Portable Learning Tool"),
 	OPS_ISREADY | OPS_KEYS | OPS_SCREEN | OPS_DIRLIST | OPS_BACKUP | OPS_VARS | 
 	OPS_FLASH | OPS_IDLIST | OPS_CLOCK | OPS_ROMDUMP |
@@ -1123,7 +1057,6 @@ const CalcFncts calc_v2 =
 		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
-	&execute,
 	&recv_screen,
 	&get_dirlist,
 	&get_memfree,
