@@ -120,44 +120,6 @@ TIEXPORT3 int TICALL ticalcs_calc_send_key(CalcHandle* handle, uint16_t key)
 	return ret;
 }
 
-/**
- * ticalcs_calc_execute:
- * @handle: a previously allocated handle
- * @ve: folder and variable name with type
- * @args: argument to pass to program (in TI-charset, aka native)
- *
- * Remotely execute a program or a FLASH application.
- * Restrictions: this is currently implemented on TI9x only and execution of FLASH
- * applications is supported thru D-USB only.
- *
- * Return value: 0 if successful, an error code otherwise.
- **/
-TIEXPORT3 int TICALL ticalcs_calc_execute(CalcHandle* handle, VarEntry* ve, const char* args)
-{
-	const CalcFncts *calc;
-	int ret = 0;
-
-	if(handle == NULL) return ERR_INVALID_HANDLE;
-	calc = handle->calc;
-
-	if(!handle->attached)
-		return ERR_NO_CABLE;
-
-	if(!handle->open)
-		return ERR_NO_CABLE;
-
-	if(handle->busy)
-		return ERR_BUSY;
-
-	ticalcs_info(_("Executing %s/%s with %s:"), ve->folder, ve->name, args);
-	handle->busy = 1;
-	if(calc->execute)
-		ret = calc->execute(handle, ve, args);
-	handle->busy = 0;
-
-	return ret;
-}
-
 /**
  * ticalcs_calc_recv_screen:
  * @handle: a previously allocated handle
@@ -206,7 +168,7 @@ TIEXPORT3 int TICALL ticalcs_calc_recv_screen(CalcHandle* handle, CalcScreenCoor
  * Return value: 0 if successful, an error code otherwise.
  **/
 TIEXPORT3 int TICALL ticalcs_calc_get_dirlist(CalcHandle* handle, 
-											 GNode** vars, GNode **apps)
+											 TNode** vars, TNode **apps)
 {
 	const CalcFncts *calc;
 	int ret = 0;
@@ -1300,7 +1262,7 @@ TIEXPORT3 int TICALL ticalcs_calc_recv_cert2(CalcHandle* handle, const char* fil
 	if(!strcmp(ext, "cer"))
 	{
 		// .cer format as generated by SDK
-		gchar *basename = g_strdup(filename);
+		gchar *basename = strdup(filename);
 		FILE *f;
 		gchar *e = tifiles_fext_get(basename);
 		int err;
@@ -1309,12 +1271,12 @@ TIEXPORT3 int TICALL ticalcs_calc_recv_cert2(CalcHandle* handle, const char* fil
 
 		content = tifiles_content_create_flash(handle->model);
 		if ((err = ticalcs_calc_recv_cert(handle, content))) {
-			g_free(basename);
+			free(basename);
 			return err;
 		}
 
 		f = fopen(basename, "wb");
-		g_free(basename);
+		free(basename);
 		if (!f)
 			return ERR_SAVE_FILE;
 		if (fwrite(content->data_part, content->data_length, 1, f) < 1)
