@@ -43,11 +43,11 @@ GList *cpca_list = NULL;
 
 CalcParam*	cp_new(uint16_t id, uint16_t size)
 {
-	CalcParam* cp = g_malloc0(sizeof(CalcParam));
+	CalcParam* cp = calloc(1, sizeof(CalcParam));
 
 	cp->id = id;
 	cp->size = size;
-	cp->data = g_malloc0(size);
+	cp->data = calloc(1, size);
 
 	cpca_list = g_list_append(cpca_list, cp);
 	return cp;
@@ -57,13 +57,13 @@ void		cp_del(CalcParam* cp)
 {
 	cpca_list = g_list_remove(cpca_list, cp);
 
-	g_free(cp->data);
-	g_free(cp);
+	free(cp->data);
+	free(cp);
 }
 
 CalcParam** cp_new_array(int size)
 {
-	CalcParam** array = g_malloc0((size+1) * sizeof(CalcParam *));
+	CalcParam** array = calloc(size+1, sizeof(CalcParam *));
 	return array;
 }
 
@@ -73,18 +73,18 @@ void cp_del_array(int size, CalcParam **params)
 
 	for(i = 0; i < size && params[i]; i++)
 		cp_del(params[i]);
-	g_free(params);
+	free(params);
 }
 
 /////////////----------------
 
 CalcAttr*	ca_new(uint16_t id, uint16_t size)
 {
-	CalcAttr* cp = g_malloc0(sizeof(CalcAttr));
+	CalcAttr* cp = calloc(1, sizeof(CalcAttr));
 
 	cp->id = id;
 	cp->size = size;
-	cp->data = g_malloc0(size);
+	cp->data = calloc(1, size);
 
 	cpca_list = g_list_append(cpca_list, cp);
 	return cp;
@@ -94,13 +94,13 @@ void		ca_del(CalcAttr* cp)
 {
 	cpca_list = g_list_remove(cpca_list, cp);
 
-	g_free(cp->data);
-	g_free(cp);
+	free(cp->data);
+	free(cp);
 }
 
 CalcAttr** ca_new_array(int size)
 {
-	CalcAttr** array = g_malloc0((size+1) * sizeof(CalcParam *));
+	CalcAttr** array = calloc(size+1, sizeof(CalcParam *));
 	return array;
 }
 
@@ -110,7 +110,7 @@ void ca_del_array(int size, CalcAttr **attrs)
 
 	for(i = 0; i < size && attrs[i]; i++)
 		ca_del(attrs[i]);
-	g_free(attrs);
+	free(attrs);
 }
 
 void cpca_purge(void)
@@ -151,9 +151,8 @@ static void byteswap(uint8_t *data, uint32_t len)
 /////////////----------------
 
 static uint16_t usb_errors[] = { 
-	0x0004, 0x0006, 0x0008, 0x0009, 0x000c, 0x000d, 0x000e, 
-	0x0011, 0x0012, 0x001c, 0x001d, 0x0022, 0x0029, 0x002b, 
-	0x0034 };
+	0x0004, 0x0006, 0x0008, 0x0009, 0x000c, 0x000e, 
+	0x0012, 0x001c, 0x001d, 0x0022, 0x002b };
 
 static int err_code(VirtualPacket *pkt)
 {
@@ -181,8 +180,8 @@ extern const VtlPktName vpkt_types[];
 										\
 		PAUSE(delay/1000);				\
 										\
-		dusb_vtl_pkt_del(pkt);				\
-		pkt = dusb_vtl_pkt_new(0, 0);		\
+		vtl_pkt_del(pkt);				\
+		pkt = vtl_pkt_new(0, 0);		\
 		TRYF(dusb_recv_data(h, pkt));	\
 	}
 
@@ -194,7 +193,7 @@ int cmd_s_mode_set(CalcHandle *h, ModeSet mode)
 	TRYF(dusb_send_buf_size_request(h, DUSB_DFL_BUF_SIZE));
 	TRYF(dusb_recv_buf_size_alloc(h, NULL));
 
-	pkt = dusb_vtl_pkt_new(sizeof(mode), VPKT_PING);
+	pkt = vtl_pkt_new(sizeof(mode), VPKT_PING);
 	pkt->data[0] = MSB(mode.arg1);
 	pkt->data[1] = LSB(mode.arg1);
 	pkt->data[2] = MSB(mode.arg2);
@@ -207,7 +206,8 @@ int cmd_s_mode_set(CalcHandle *h, ModeSet mode)
 	pkt->data[9] = LSB(mode.arg5);
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  PC->TI: Ping / Set Mode");
 	ticalcs_info("   %04x %04x %04x %04x %04x", mode.arg1, mode.arg2, mode.arg3, mode.arg4, mode.arg5);
 
 	return 0;
@@ -218,14 +218,15 @@ int cmd_s_os_begin(CalcHandle *h, uint32_t size)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(11, VPKT_OS_BEGIN);
+	pkt = vtl_pkt_new(11, VPKT_OS_BEGIN);
 	pkt->data[7] = MSB(MSW(size));
 	pkt->data[8] = LSB(MSW(size));
 	pkt->data[9] = MSB(LSW(size));
 	pkt->data[10]= LSB(LSW(size));
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  PC->TI: OS Transfer Begin");
 	ticalcs_info("   size = %08x (%i)", size, size);
 
 	return 0;
@@ -236,7 +237,7 @@ int cmd_r_os_ack(CalcHandle *h, uint32_t *size)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(0, 0);
+	pkt = vtl_pkt_new(0, 0);
 	TRYF(dusb_recv_data(h, pkt));
 
 	CATCH_DELAY();
@@ -248,7 +249,8 @@ int cmd_r_os_ack(CalcHandle *h, uint32_t *size)
 	
 	*size = (pkt->data[0] << 24) | (pkt->data[1] << 16) | (pkt->data[2] << 8) | (pkt->data[3] << 0);
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  TI->PC: OS Transfer Ack");
 	ticalcs_info("   size = %08x (%i)", *size, *size);
 
 	return 0;
@@ -258,7 +260,7 @@ static int s_os(uint8_t type, CalcHandle *h, uint16_t addr, uint8_t page, uint8_
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(4 + size, type);
+	pkt = vtl_pkt_new(4 + size, type);
 
 	pkt->data[0] = MSB(addr);
 	pkt->data[1] = LSB(addr);
@@ -267,7 +269,8 @@ static int s_os(uint8_t type, CalcHandle *h, uint16_t addr, uint8_t page, uint8_
 	memcpy(pkt->data+4, data, size);
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  TI->PC: %s", type == VPKT_OS_HEADER ? "OS Header" : "OS Data");
 	ticalcs_info("   addr=%04x, page=%02x, flag=%02x, size=%04x", addr, page, flag, size);
 
 	return 0;
@@ -290,11 +293,12 @@ int cmd_s_os_header_89(CalcHandle *h, uint32_t size, uint8_t *data)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(size, VPKT_OS_HEADER);
+	pkt = vtl_pkt_new(size, VPKT_OS_HEADER);
 	memcpy(pkt->data, data, size);
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  TI->PC: OS Header");
 	ticalcs_info("   size = %08x (%i)", size, size);
 
 	return 0;
@@ -305,11 +309,12 @@ int cmd_s_os_data_89(CalcHandle *h, uint32_t size, uint8_t *data)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(size, VPKT_OS_DATA);
+	pkt = vtl_pkt_new(size, VPKT_OS_DATA);
 	memcpy(pkt->data, data, size);
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  TI->PC: OS Data");
 	ticalcs_info("   size = %08x (%i)", size, size);
 
 	return 0;
@@ -320,7 +325,7 @@ int cmd_r_eot_ack(CalcHandle *h)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(0, 0);
+	pkt = vtl_pkt_new(0, 0);
 	TRYF(dusb_recv_data(h, pkt));
 
 	CATCH_DELAY();
@@ -330,7 +335,8 @@ int cmd_r_eot_ack(CalcHandle *h)
 	else if(pkt->type != VPKT_EOT_ACK)
 		return ERR_INVALID_PACKET;
 	
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  TI->PC: EOT Ack");
 
 	return 0;
 }
@@ -341,7 +347,7 @@ int cmd_s_param_request(CalcHandle *h, int npids, uint16_t *pids)
 	VirtualPacket* pkt;
 	int i;
 
-	pkt = dusb_vtl_pkt_new((npids + 1) * sizeof(uint16_t), VPKT_PARM_REQ);
+	pkt = vtl_pkt_new((npids + 1) * sizeof(uint16_t), VPKT_PARM_REQ);
 
 	pkt->data[0] = MSB(npids);
 	pkt->data[1] = LSB(npids);
@@ -354,7 +360,8 @@ int cmd_s_param_request(CalcHandle *h, int npids, uint16_t *pids)
 
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  PC->TI: Parameter Request");
 	ticalcs_info("   npids=%i", npids);
 
 	return 0;
@@ -366,7 +373,7 @@ int cmd_r_param_data(CalcHandle *h, int nparams, CalcParam **params)
 	VirtualPacket* pkt;
 	int i, j;
 
-	pkt = dusb_vtl_pkt_new(0, 0);
+	pkt = vtl_pkt_new(0, 0);
 	TRYF(dusb_recv_data(h, pkt));
 
 	CATCH_DELAY();
@@ -388,13 +395,14 @@ int cmd_r_param_data(CalcHandle *h, int nparams, CalcParam **params)
 		if(s->ok)
 		{
 			s->size = pkt->data[j++] << 8; s->size |= pkt->data[j++];
-			s->data = (uint8_t *)g_malloc0(s->size);
+			s->data = (uint8_t *)calloc(1, s->size);
 			memcpy(s->data, &pkt->data[j], s->size);
 			j += s->size;
 		}
 	}
 	
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  TI->PC: Parameter Data");
 	ticalcs_info("   nparams=%i", nparams);
 
 	return 0;
@@ -407,7 +415,7 @@ int cmd_s_dirlist_request(CalcHandle *h, int naids, uint16_t *aids)
 	int i;
 	int j = 0;
 
-	pkt = dusb_vtl_pkt_new(4 + 2*naids + 7, VPKT_DIR_REQ);
+	pkt = vtl_pkt_new(4 + 2*naids + 7, VPKT_DIR_REQ);
 
 	pkt->data[j++] = MSB(MSW(naids));
 	pkt->data[j++] = LSB(MSW(naids));
@@ -427,14 +435,15 @@ int cmd_s_dirlist_request(CalcHandle *h, int naids, uint16_t *aids)
 
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  PC->TI: Directory Listing");
 	ticalcs_info("   naids=%i", naids);
 
 	return 0;
 }
 
 // 0x000A: variable header (name is utf-8)
-// beware: attr array contents is allocated by function
+// beware: attr array is allocated by function
 int cmd_r_var_header(CalcHandle *h, char *folder, char *name, CalcAttr **attr)
 {
 	VirtualPacket* pkt;
@@ -443,14 +452,14 @@ int cmd_r_var_header(CalcHandle *h, char *folder, char *name, CalcAttr **attr)
 	int nattr;
 	int i, j;
 
-	pkt = dusb_vtl_pkt_new(0, 0);
+	pkt = vtl_pkt_new(0, 0);
 	TRYF(dusb_recv_data(h, pkt));
 
 	CATCH_DELAY();
 
 	if(pkt->type == VPKT_EOT)
 	{
-		dusb_vtl_pkt_del(pkt);
+		vtl_pkt_del(pkt);
 		return ERR_EOT;
 	}
 	else if(pkt->type == VPKT_ERROR)
@@ -486,14 +495,15 @@ int cmd_r_var_header(CalcHandle *h, char *folder, char *name, CalcAttr **attr)
 		if(s->ok)
 		{
 			s->size = pkt->data[j++] << 8; s->size |= pkt->data[j++];
-			s->data = (uint8_t *)g_malloc0(s->size);
+			s->data = (uint8_t *)calloc(1, s->size);
 			memcpy(s->data, &pkt->data[j], s->size);
 			j += s->size;
 		}
 	}
 	
-	dusb_vtl_pkt_del(pkt);
-	ticalcs_info("   folder=%s, name=%s", folder, name);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  TI->PC: Variable Header");
+	ticalcs_info("   folder=<%s>, name=<%s>", folder, name);
 
 	return 0;
 }
@@ -510,7 +520,7 @@ int cmd_s_rts(CalcHandle *h, const char *folder, const char *name, uint32_t size
 	if(strlen(folder))
 		pks += strlen(folder)+1;
 	for(i = 0; i < nattrs; i++) pks += 4 + attrs[i]->size;
-	pkt = dusb_vtl_pkt_new(pks, VPKT_RTS);
+	pkt = vtl_pkt_new(pks, VPKT_RTS);
 
 	if(strlen(folder))
 	{
@@ -546,8 +556,9 @@ int cmd_s_rts(CalcHandle *h, const char *folder, const char *name, uint32_t size
 
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
-	ticalcs_info("   folder=%s, name=%s, size=%i, nattrs=%i", folder, name, size, nattrs);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  PC->TI: Request to Send");
+	ticalcs_info("   folder=<%s>, name=<%s>, size=%i, nattrs=%i", folder, name, size, nattrs);
 
 	return 0;
 }
@@ -566,7 +577,7 @@ int cmd_s_var_request(CalcHandle *h, const char *folder, const char *name,
 	if(strlen(folder)) pks += strlen(folder)+1;
 	for(i = 0; i < nattrs; i++) pks += 4 + attrs[i]->size;
 	pks += 2;
-	pkt = dusb_vtl_pkt_new(pks, VPKT_VAR_REQ);
+	pkt = vtl_pkt_new(pks, VPKT_VAR_REQ);
 
 	if(strlen(folder))
 	{
@@ -609,8 +620,9 @@ int cmd_s_var_request(CalcHandle *h, const char *folder, const char *name,
 
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
-	ticalcs_info("   folder=%s, name=%s, naids=%i, nattrs=%i", folder, name, naids, nattrs);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  PC->TI: Request Variable");
+	ticalcs_info("   folder=<%s>, name=<%s>, naids=%i, nattrs=%i", folder, name, naids, nattrs);
 
 	return 0;
 }
@@ -620,7 +632,7 @@ int cmd_r_var_content(CalcHandle *h, uint32_t *size, uint8_t **data)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(0, 0);
+	pkt = vtl_pkt_new(0, 0);
 	TRYF(dusb_recv_data(h, pkt));
 
 	CATCH_DELAY();
@@ -633,10 +645,11 @@ int cmd_r_var_content(CalcHandle *h, uint32_t *size, uint8_t **data)
 	if(size != NULL)
 		*size = pkt->size;
 
-	*data = g_malloc0(pkt->size);
+	*data = calloc(pkt->size, 1);
 	memcpy(*data, pkt->data, pkt->size);
 	
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  PC->TI: Variable Contents");
 	ticalcs_info("   size=%i", size);
 
 	return 0;
@@ -647,12 +660,13 @@ int cmd_s_var_content(CalcHandle *h, uint32_t size, uint8_t *data)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(size, VPKT_VAR_CNTS);
+	pkt = vtl_pkt_new(size, VPKT_VAR_CNTS);
 
 	memcpy(pkt->data, data, size);
 	TRYF(dusb_send_data(h, pkt));
 	
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  PC->TI: Variable Contents");
 	ticalcs_info("   size=%i", size);
 
 	return 0;
@@ -663,7 +677,7 @@ int cmd_s_param_set(CalcHandle *h, const CalcParam *param)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(2 + 2 + param->size, VPKT_PARM_SET);
+	pkt = vtl_pkt_new(2 + 2 + param->size, VPKT_PARM_SET);
 
 	pkt->data[0] = MSB(param->id);
 	pkt->data[1] = LSB(param->id);
@@ -673,7 +687,7 @@ int cmd_s_param_set(CalcHandle *h, const CalcParam *param)
 
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
 	ticalcs_info("   pid=%04x, size=%04x", param->id, param->size);
 
 	return 0;
@@ -692,7 +706,7 @@ int cmd_s_var_delete(CalcHandle *h, const char *folder, const char *name, int na
 		pks += strlen(folder)+1;
 	for(i = 0; i < nattrs; i++) pks += 4 + attrs[i]->size;
 	pks += 5;
-	pkt = dusb_vtl_pkt_new(pks, VPKT_DEL_VAR);
+	pkt = vtl_pkt_new(pks, VPKT_DEL_VAR);
 
 	if(strlen(folder))
 	{
@@ -726,65 +740,9 @@ int cmd_s_var_delete(CalcHandle *h, const char *folder, const char *name, int na
 
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
-	ticalcs_info("   folder=%s, name=%s, nattrs=%i", folder, name, nattrs);
-
-	return 0;
-}
-
-// 0x0011: remote control
-int cmd_s_execute(CalcHandle *h, const char *folder, const char *name, 
-					uint8_t action, const char *args, uint16_t code)
-{
-	VirtualPacket* pkt;
-	int pks;
-	int j = 0;
-
-	pks = 3;
-	if(args) pks += strlen(args); else pks += 2;
-	if(strlen(folder)) pks += strlen(folder)+1;
-	if(strlen(name)) pks += strlen(name)+1;
-	pkt = dusb_vtl_pkt_new(pks, VPKT_EXECUTE);
-
-	pkt->data[j++] = strlen(folder);
-	if(strlen(folder))
-	{		
-		memcpy(pkt->data + j, folder, strlen(folder)+1);
-		j += strlen(folder)+1;
-	}
-
-	pkt->data[j++] = strlen(name);
-	if(strlen(name))
-	{		
-		memcpy(pkt->data + j, name, strlen(name)+1);
-		j += strlen(name)+1;
-	}
-	
-	pkt->data[j++] = action;
-
-	if(action != EID_KEY && args != NULL)
-		memcpy(pkt->data + j, args, strlen(args));
-	else if(action == EID_KEY || args == NULL)
-	{
-		if(h->model == CALC_TI89T_USB)
-		{
-			pkt->data[j++] = MSB(code);
-			pkt->data[j++] = LSB(code);
-		}
-		else if(h->model == CALC_TI84P_USB)
-		{
-			pkt->data[j++] = LSB(code);
-			pkt->data[j++] = MSB(code);
-		}
-	}
-
-	TRYF(dusb_send_data(h, pkt));
-
-	dusb_vtl_pkt_del(pkt);
-	if(args)
-		ticalcs_info("   action=%i, folder=%s, name=%s, args=%s", action, folder, name, args);
-	else
-		ticalcs_info("   action=%i, keycode=%04x", action, code);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  PC->TI: Delete Variable");
+	ticalcs_info("   folder=<%s>, name=<%s>, nattrs=%i", folder, name, nattrs);
 
 	return 0;
 }
@@ -794,7 +752,7 @@ int cmd_r_mode_ack(CalcHandle *h)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(0, 0);
+	pkt = vtl_pkt_new(0, 0);
 	TRYF(dusb_recv_data(h, pkt));
 
 	CATCH_DELAY();
@@ -804,7 +762,8 @@ int cmd_r_mode_ack(CalcHandle *h)
 	else if(pkt->type != VPKT_MODE_SET)
 		return ERR_INVALID_PACKET;
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  TI->PC: Mode Setting Ack");
 
 	return 0;
 }
@@ -814,7 +773,7 @@ int cmd_r_data_ack(CalcHandle *h)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(0, 0);
+	pkt = vtl_pkt_new(0, 0);
 	TRYF(dusb_recv_data(h, pkt));
 
 	CATCH_DELAY();
@@ -824,7 +783,8 @@ int cmd_r_data_ack(CalcHandle *h)
 	else if(pkt->type != VPKT_DATA_ACK)
 		return ERR_INVALID_PACKET;
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  TI->PC: Data Ack");
 
 	return 0;
 }
@@ -834,7 +794,7 @@ int cmd_r_delay_ack(CalcHandle *h)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(0, 0);
+	pkt = vtl_pkt_new(0, 0);
 	TRYF(dusb_recv_data(h, pkt));
 
 	if(pkt->type == VPKT_ERROR)
@@ -844,7 +804,8 @@ int cmd_r_delay_ack(CalcHandle *h)
 
 	PAUSE(100);
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  TI->PC: Delay Ack");
 
 	return 0;
 }
@@ -854,10 +815,11 @@ int cmd_s_eot(CalcHandle *h)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(0, VPKT_EOT);
+	pkt = vtl_pkt_new(0, VPKT_EOT);
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  PC->TI: End of Transmission");
 
 	return 0;
 }
@@ -867,7 +829,7 @@ int cmd_r_eot(CalcHandle *h)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(0, 0);
+	pkt = vtl_pkt_new(0, 0);
 	TRYF(dusb_recv_data(h, pkt));
 
 	CATCH_DELAY();
@@ -877,7 +839,8 @@ int cmd_r_eot(CalcHandle *h)
 	else if(pkt->type != VPKT_EOT)
 		return ERR_INVALID_PACKET;
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  TI->PC: End of Transmission");
 
 	return 0;
 }
@@ -887,13 +850,14 @@ int cmd_s_error(CalcHandle *h, uint16_t code)
 {
 	VirtualPacket* pkt;
 
-	pkt = dusb_vtl_pkt_new(2, VPKT_ERROR);
+	pkt = vtl_pkt_new(2, VPKT_ERROR);
 
 	pkt->data[0] = MSB(code);
 	pkt->data[1] = LSB(code);
 	TRYF(dusb_send_data(h, pkt));
 
-	dusb_vtl_pkt_del(pkt);
+	vtl_pkt_del(pkt);
+	//ticalcs_info("  PC->TI: Error");
 	ticalcs_info("   code = %04x", code);
 
 	return 0;
