@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: error.c 4139 2008-01-26 14:30:11Z roms $ */
+/* $Id: error.c 3001 2006-10-13 15:48:34Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Livin
@@ -28,13 +28,9 @@
 #include "error.h"
 #include "logging.h"
 
-// extern helpers
-extern void dusb_vtl_pkt_purge(void);
-extern void nsp_vtl_pkt_purge(void);
+extern void vtl_pkt_purge(void);
 extern void cpca_purge(void);
 
-extern int nsp_reset;
-
 /**
  * ticalcs_error_get:
  * @number: error number (see error.h for list).
@@ -53,14 +49,8 @@ TIEXPORT3 int TICALL ticalcs_error_get(CalcError number, char **message)
 {
 	char error_msg[2048];
 
-	// free memory
-	dusb_vtl_pkt_purge();
+	vtl_pkt_purge();
 	cpca_purge();
-	nsp_vtl_pkt_purge();
-
-	// force reset/address request
-	//ticalcs_info("force reset !\n");
-	nsp_reset = 0;
 
 	g_assert (message != NULL);
 
@@ -76,21 +66,21 @@ TIEXPORT3 int TICALL ticalcs_error_get(CalcError number, char **message)
 
 	case ERR_NOT_READY:
 		*message = g_strconcat(
-    		_("Msg: calculator is not ready."),
+    		_("Msg: Calculator is not ready."),
     		"\n",
     		 _("Cause: the calculator is busy (Var-Link menu, Window, ...). Press HOME..."),
 			 NULL);
 		break;
 
 	case ERR_CHECKSUM:
-		strcpy(error_msg, _("Msg: checksum error."));
+		strcpy(error_msg, _("Msg: Checksum error."));
 		strcat(error_msg, "\n");
 		strcat(error_msg, _("Cause: a transmission error. Try again."));
 		*message = g_strdup(error_msg);
     break;
 
 	case ERR_INVALID_HOST:
-		strcpy(error_msg, _("Msg: invalid host ID."));
+		strcpy(error_msg, _("Msg: Invalid host ID."));
 		strcat(error_msg, "\n");
 		strcat(error_msg,
 		   _
@@ -99,7 +89,7 @@ TIEXPORT3 int TICALL ticalcs_error_get(CalcError number, char **message)
     break;
 
 	case ERR_INVALID_TARGET:
-		strcpy(error_msg, _("Msg: invalid target ID."));
+		strcpy(error_msg, _("Msg: Invalid target ID."));
 		strcat(error_msg, "\n");
 		strcat(error_msg,
 		   _
@@ -108,7 +98,7 @@ TIEXPORT3 int TICALL ticalcs_error_get(CalcError number, char **message)
     break;
 
 	case ERR_INVALID_CMD:
-		strcpy(error_msg, _("Msg: invalid command ID."));
+		strcpy(error_msg, _("Msg: Invalid command ID."));
 		strcat(error_msg, "\n");
 		strcat(error_msg,
 		   _
@@ -117,7 +107,7 @@ TIEXPORT3 int TICALL ticalcs_error_get(CalcError number, char **message)
     break;
 
 	case ERR_EOT:
-		strcpy(error_msg, _("Msg: not really an error, should not appear!"));
+		strcpy(error_msg, _("Msg: Not really an error, should not appear!"));
 		strcat(error_msg, "\n");
 		strcat(error_msg, _("Cause: a bug. Drop us an email!"));
 		*message = g_strdup(error_msg);
@@ -125,7 +115,7 @@ TIEXPORT3 int TICALL ticalcs_error_get(CalcError number, char **message)
 
 	case ERR_VAR_REJECTED:
 		strcpy(error_msg,
-		   _("Msg: contents has been refused."));
+		   _("Msg: The content has been refused."));
 		strcat(error_msg, "\n");
 		strcat(error_msg,
 		   _
@@ -143,14 +133,14 @@ TIEXPORT3 int TICALL ticalcs_error_get(CalcError number, char **message)
 	case ERR_NACK:
 		strcpy(error_msg, _("NACK received."));
 		strcat(error_msg, "\n");
-		strcat(error_msg, _("Cause: the command has been refused."));
+		strcat(error_msg, _("Cause: the command has been refused.\n"));
 		*message = g_strdup(error_msg);
     break;
 
 	case ERR_INVALID_PACKET:
 		strcpy(error_msg, _("Invalid packet."));
 		strcat(error_msg, "\n");
-		strcat(error_msg, _("Cause: a transmission error."));
+		strcat(error_msg, _("Cause: a transmission error.\n"));
 		*message = g_strdup(error_msg);
     break;
 
@@ -160,7 +150,7 @@ TIEXPORT3 int TICALL ticalcs_error_get(CalcError number, char **message)
   case ERR_NO_CABLE:
 		strcpy(error_msg, _("The cable can not be used."));
 		strcat(error_msg, "\n");
-		strcat(error_msg, _("Cause: the cable has not been initialized due to a previous/current error."));
+		strcat(error_msg, _("Cause: the cable has not been initialized due to a previous/current error.\n"));
 		*message = g_strdup(error_msg);
 	  break;
 
@@ -173,7 +163,7 @@ TIEXPORT3 int TICALL ticalcs_error_get(CalcError number, char **message)
   case ERR_VOID_FUNCTION:
 	case ERR_UNSUPPORTED:
 		strcpy(error_msg,
-		   _("Msg: this function does not exist for this calculator."));
+		   _("Msg: This function does not exist for this calculator."));
 		strcat(error_msg, "\n");
 		strcat(error_msg,
 		   _
@@ -182,7 +172,7 @@ TIEXPORT3 int TICALL ticalcs_error_get(CalcError number, char **message)
     break;
 
 case ERR_OUT_OF_MEMORY:
-		strcpy(error_msg, _("Msg: calculator out of memory."));
+		strcpy(error_msg, _("Msg: Calculator out of memory."));
 		strcat(error_msg, "\n");
 		strcat(error_msg,
 		   _
@@ -191,14 +181,14 @@ case ERR_OUT_OF_MEMORY:
     break;
 
   case ERR_OPEN_FILE:
-		strcpy(error_msg, _("Msg: unable to open (reading) the file."));
+		strcpy(error_msg, _("Msg: Unable to open (reading) the file."));
 		strcat(error_msg, "\n");
 		strcat(error_msg, _("Cause: disk space or permissions."));
 		*message = g_strdup(error_msg);
     break;
 
   case ERR_SAVE_FILE:
-		strcpy(error_msg, _("Msg: unable to open (writing) the file."));
+		strcpy(error_msg, _("Msg: Unable to open (writing) the file."));
 		strcat(error_msg, "\n");
 		strcat(error_msg, _("Cause: disk space or permissions."));
 		*message = g_strdup(error_msg);
@@ -230,7 +220,7 @@ case ERR_OUT_OF_MEMORY:
 		strcpy(error_msg, _("There is nothing to backup."));
 		strcat(error_msg, "\n");
 		strcat(error_msg,
-		   _("Cause: 0 variables stored onto your calculator."));
+		   _("Cause: 0 variables stored onto your calculator.\n"));
 		*message = g_strdup(error_msg);
     break;
 
@@ -238,16 +228,16 @@ case ERR_OUT_OF_MEMORY:
 		strcpy(error_msg, _("Invalid TiCalcs handle."));
 		strcat(error_msg, "\n");
 		strcat(error_msg,
-		   _("Cause: bad cable or calc model."));
+		   _("Cause: bad cable or calc model.\n"));
 		*message = g_strdup(error_msg);
     break;
 
   case ERR_CALC_ERROR1:	// must be synch'ed with cmd89.c (static uint8_t dbus_errors[])
-		strcpy(error_msg, _("Msg: hand-held returned an error."));
+		strcpy(error_msg, _("Msg: Hand-held returned an error (not catched)."));
 		strcat(error_msg, "\n");
 		strcat(error_msg,
 		   _
-		   ("Cause: hand-held returned an uncaught error. Please report log."));
+		   ("Cause: hand-held returned an uncatched error. Please report log."));
 		*message = g_strdup(error_msg);
     break;
   case ERR_CALC_ERROR1+1:
@@ -271,20 +261,16 @@ case ERR_OUT_OF_MEMORY:
 		*message = g_strdup(error_msg);
     break;
   case ERR_CALC_ERROR1+6:
-		strcpy(error_msg, _("Msg: invalid folder name."));
-		*message = g_strdup(error_msg);
-    break;
-  case ERR_CALC_ERROR1+7:
 		strcpy(error_msg, _("Msg: malformed RTS packet (AMS version conflict)."));
 		*message = g_strdup(error_msg);
     break;
 
   case ERR_CALC_ERROR2:	// must be synch'ed with dusb_cmd.c (static uint16_t usb_errors[])
-		strcpy(error_msg, _("Msg: hand-held returned an error (not caught)."));
+		strcpy(error_msg, _("Msg: Hand-held returned an error (not catched)."));
 		strcat(error_msg, "\n");
 		strcat(error_msg,
 		   _
-		   ("Cause: hand-held returned an uncaught error. Please report log."));
+		   ("Cause: hand-held returned an uncatched error. Please report log."));
 		*message = g_strdup(error_msg);
     break;
   case ERR_CALC_ERROR2+1:
@@ -312,77 +298,24 @@ case ERR_OUT_OF_MEMORY:
 		*message = g_strdup(error_msg);
     break;
   case ERR_CALC_ERROR2+7:
-	    strcpy(error_msg, _("Msg: invalid name."));
-		*message = g_strdup(error_msg);
-    break;
-  case ERR_CALC_ERROR2+8:
-	    strcpy(error_msg, _("Msg: busy?."));
-		*message = g_strdup(error_msg);
-    break;
-  case ERR_CALC_ERROR2+9:
 	    strcpy(error_msg, _("Msg: can't overwrite, variable is locked."));
 		*message = g_strdup(error_msg);
     break;
-  case ERR_CALC_ERROR2+10:
+  case ERR_CALC_ERROR2+8:
 	    strcpy(error_msg, _("Msg: mode token too small."));
 		*message = g_strdup(error_msg);
     break;
-  case ERR_CALC_ERROR2+11:
+  case ERR_CALC_ERROR2+9:
 	    strcpy(error_msg, _("Msg: mode token too large."));
 		*message = g_strdup(error_msg);
     break;
-  case ERR_CALC_ERROR2+12:
+  case ERR_CALC_ERROR2+10:
 	    strcpy(error_msg, _("Msg: invalid parameter ID."));
 		*message = g_strdup(error_msg);
-    break;
-  case ERR_CALC_ERROR2+13:
-	    strcpy(error_msg, _("Msg: remote control?"));
-		*message = g_strdup(error_msg);
-    break;
-  case ERR_CALC_ERROR2+14:
+    break;  
+  case ERR_CALC_ERROR2+11:
 	    strcpy(error_msg, _("Msg: battery low."));
 		*message = g_strdup(error_msg);
-    break;
-  case ERR_CALC_ERROR2+15:
-	    strcpy(error_msg, _("Msg: hand-held is busy (set your calculator to HOME screen)."));
-		*message = g_strdup(error_msg);
-    break;
-
-  case ERR_CALC_ERROR3+0:
-		strcpy(error_msg, _("Msg: hand-held returned an error (not caught)."));
-		strcat(error_msg, "\n");
-		strcat(error_msg,
-		   _
-		   ("Cause: hand-held returned an uncaught error. Please report log."));
-		*message = g_strdup(error_msg);
-    break;
-	case ERR_CALC_ERROR3+1:
-	    strcpy(error_msg, _("Msg: OS installation failed. File is corrupted/wrong."));
-		*message = g_strdup(error_msg);
-    break;
-	case ERR_CALC_ERROR3+2:
-	    strcpy(error_msg, _("Msg: the directory does not exist."));
-		*message = g_strdup(error_msg);
-    break;
-	case ERR_CALC_ERROR3+3:
-	    strcpy(error_msg, _("Msg: the directory name is invalid."));
-		*message = g_strdup(error_msg);
-    break;
-	case ERR_CALC_ERROR3+4:
-	    strcpy(error_msg, _("Msg: not currently listing a directory."));
-		*message = g_strdup(error_msg);
-    break;
-	case ERR_CALC_ERROR3+5:
-	    strcpy(error_msg, _("Msg: no more files to list."));
-		*message = g_strdup(error_msg);
-    break;
-	case ERR_CALC_ERROR3+6:
-	    strcpy(error_msg, _("Msg: the file name is invalid."));
-		*message = g_strdup(error_msg);
-    break;
-	case ERR_CALC_ERROR3+7:
-	    strcpy(error_msg, _("Msg: no file extension."));
-		*message = g_strdup(error_msg);
     break;
 
 	default:
