@@ -1,8 +1,8 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id$ */
+/* $Id: pause.h 1179 2005-06-06 14:42:32Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2005  Romain Liévin
+ *  Copyright (C) 1999-2005  Romain Livin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,8 +15,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software Foundation,
- *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #ifndef __TICALCS_PAUSE__
@@ -26,13 +26,12 @@
 
 #define PAUSE_BETWEEN_VARS	250	// 250ms
 
-#if defined(__LINUX__) || defined(__MACOSX__) || defined(__BSD__) || defined(__ANDROID__)
+#if defined(__LINUX__) || defined(__MACOSX__) || defined(__BSD__)
 # include <unistd.h>
-# define PAUSE(x)  usleep(1000*(x))
+# define PAUSE(x)  usleep(1000*(x));
 #elif defined(__WIN32__)
-# define WIN32_LEAN_AND_MEAN
 # include <windows.h>
-# define PAUSE(x)  Sleep((x))
+# define PAUSE(x)  Sleep((x));
 #endif
 
 #endif
